@@ -154,6 +154,7 @@ class Exceptions:
     InvalidEC2TagCombinationException: Type[Boto3ClientError]
     InvalidEC2TagException: Type[Boto3ClientError]
     InvalidECSServiceException: Type[Boto3ClientError]
+    InvalidExternalIdException: Type[Boto3ClientError]
     InvalidFileExistsBehaviorException: Type[Boto3ClientError]
     InvalidGitHubAccountTokenException: Type[Boto3ClientError]
     InvalidGitHubAccountTokenNameException: Type[Boto3ClientError]
@@ -208,7 +209,7 @@ class Exceptions:
 
 class CodeDeployClient:
     """
-    [CodeDeploy.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client)
+    [CodeDeploy.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client)
     """
 
     exceptions: Exceptions
@@ -217,59 +218,59 @@ class CodeDeployClient:
         self, tags: List[TagTypeDef], instanceNames: List[str]
     ) -> None:
         """
-        [Client.add_tags_to_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.add_tags_to_on_premises_instances)
+        [Client.add_tags_to_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.add_tags_to_on_premises_instances)
         """
 
     def batch_get_application_revisions(
         self, applicationName: str, revisions: List[RevisionLocationTypeDef]
     ) -> BatchGetApplicationRevisionsOutputTypeDef:
         """
-        [Client.batch_get_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_application_revisions)
+        [Client.batch_get_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_application_revisions)
         """
 
     def batch_get_applications(
         self, applicationNames: List[str]
     ) -> BatchGetApplicationsOutputTypeDef:
         """
-        [Client.batch_get_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_applications)
+        [Client.batch_get_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_applications)
         """
 
     def batch_get_deployment_groups(
         self, applicationName: str, deploymentGroupNames: List[str]
     ) -> BatchGetDeploymentGroupsOutputTypeDef:
         """
-        [Client.batch_get_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_groups)
+        [Client.batch_get_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_groups)
         """
 
     def batch_get_deployment_instances(
         self, deploymentId: str, instanceIds: List[str]
     ) -> BatchGetDeploymentInstancesOutputTypeDef:
         """
-        [Client.batch_get_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_instances)
+        [Client.batch_get_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_instances)
         """
 
     def batch_get_deployment_targets(
         self, deploymentId: str = None, targetIds: List[str] = None
     ) -> BatchGetDeploymentTargetsOutputTypeDef:
         """
-        [Client.batch_get_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_targets)
+        [Client.batch_get_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_targets)
         """
 
     def batch_get_deployments(self, deploymentIds: List[str]) -> BatchGetDeploymentsOutputTypeDef:
         """
-        [Client.batch_get_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployments)
+        [Client.batch_get_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployments)
         """
 
     def batch_get_on_premises_instances(
         self, instanceNames: List[str]
     ) -> BatchGetOnPremisesInstancesOutputTypeDef:
         """
-        [Client.batch_get_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_on_premises_instances)
+        [Client.batch_get_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_on_premises_instances)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.can_paginate)
         """
 
     def continue_deployment(
@@ -278,7 +279,7 @@ class CodeDeployClient:
         deploymentWaitType: Literal["READY_WAIT", "TERMINATION_WAIT"] = None,
     ) -> None:
         """
-        [Client.continue_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.continue_deployment)
+        [Client.continue_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.continue_deployment)
         """
 
     def create_application(
@@ -288,7 +289,7 @@ class CodeDeployClient:
         tags: List[TagTypeDef] = None,
     ) -> CreateApplicationOutputTypeDef:
         """
-        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.create_application)
+        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.create_application)
         """
 
     def create_deployment(
@@ -305,7 +306,7 @@ class CodeDeployClient:
         fileExistsBehavior: Literal["DISALLOW", "OVERWRITE", "RETAIN"] = None,
     ) -> CreateDeploymentOutputTypeDef:
         """
-        [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment)
+        [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment)
         """
 
     def create_deployment_config(
@@ -316,7 +317,7 @@ class CodeDeployClient:
         computePlatform: Literal["Server", "Lambda", "ECS"] = None,
     ) -> CreateDeploymentConfigOutputTypeDef:
         """
-        [Client.create_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_config)
+        [Client.create_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_config)
         """
 
     def create_deployment_group(
@@ -340,36 +341,41 @@ class CodeDeployClient:
         tags: List[TagTypeDef] = None,
     ) -> CreateDeploymentGroupOutputTypeDef:
         """
-        [Client.create_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_group)
+        [Client.create_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_group)
         """
 
     def delete_application(self, applicationName: str) -> None:
         """
-        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.delete_application)
+        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.delete_application)
         """
 
     def delete_deployment_config(self, deploymentConfigName: str) -> None:
         """
-        [Client.delete_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_config)
+        [Client.delete_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_config)
         """
 
     def delete_deployment_group(
         self, applicationName: str, deploymentGroupName: str
     ) -> DeleteDeploymentGroupOutputTypeDef:
         """
-        [Client.delete_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_group)
+        [Client.delete_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_group)
         """
 
     def delete_git_hub_account_token(
         self, tokenName: str = None
     ) -> DeleteGitHubAccountTokenOutputTypeDef:
         """
-        [Client.delete_git_hub_account_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.delete_git_hub_account_token)
+        [Client.delete_git_hub_account_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.delete_git_hub_account_token)
+        """
+
+    def delete_resources_by_external_id(self, externalId: str = None) -> Dict[str, Any]:
+        """
+        [Client.delete_resources_by_external_id documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.delete_resources_by_external_id)
         """
 
     def deregister_on_premises_instance(self, instanceName: str) -> None:
         """
-        [Client.deregister_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.deregister_on_premises_instance)
+        [Client.deregister_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.deregister_on_premises_instance)
         """
 
     def generate_presigned_url(
@@ -380,55 +386,55 @@ class CodeDeployClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.generate_presigned_url)
         """
 
     def get_application(self, applicationName: str) -> GetApplicationOutputTypeDef:
         """
-        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_application)
+        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_application)
         """
 
     def get_application_revision(
         self, applicationName: str, revision: RevisionLocationTypeDef
     ) -> GetApplicationRevisionOutputTypeDef:
         """
-        [Client.get_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_application_revision)
+        [Client.get_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_application_revision)
         """
 
     def get_deployment(self, deploymentId: str) -> GetDeploymentOutputTypeDef:
         """
-        [Client.get_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment)
+        [Client.get_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment)
         """
 
     def get_deployment_config(self, deploymentConfigName: str) -> GetDeploymentConfigOutputTypeDef:
         """
-        [Client.get_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_config)
+        [Client.get_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_config)
         """
 
     def get_deployment_group(
         self, applicationName: str, deploymentGroupName: str
     ) -> GetDeploymentGroupOutputTypeDef:
         """
-        [Client.get_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_group)
+        [Client.get_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_group)
         """
 
     def get_deployment_instance(
         self, deploymentId: str, instanceId: str
     ) -> GetDeploymentInstanceOutputTypeDef:
         """
-        [Client.get_deployment_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_instance)
+        [Client.get_deployment_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_instance)
         """
 
     def get_deployment_target(
         self, deploymentId: str = None, targetId: str = None
     ) -> GetDeploymentTargetOutputTypeDef:
         """
-        [Client.get_deployment_target documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_target)
+        [Client.get_deployment_target documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_target)
         """
 
     def get_on_premises_instance(self, instanceName: str) -> GetOnPremisesInstanceOutputTypeDef:
         """
-        [Client.get_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.get_on_premises_instance)
+        [Client.get_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.get_on_premises_instance)
         """
 
     def list_application_revisions(
@@ -442,24 +448,24 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListApplicationRevisionsOutputTypeDef:
         """
-        [Client.list_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_application_revisions)
+        [Client.list_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_application_revisions)
         """
 
     def list_applications(self, nextToken: str = None) -> ListApplicationsOutputTypeDef:
         """
-        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_applications)
+        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_applications)
         """
 
     def list_deployment_configs(self, nextToken: str = None) -> ListDeploymentConfigsOutputTypeDef:
         """
-        [Client.list_deployment_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_configs)
+        [Client.list_deployment_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_configs)
         """
 
     def list_deployment_groups(
         self, applicationName: str, nextToken: str = None
     ) -> ListDeploymentGroupsOutputTypeDef:
         """
-        [Client.list_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_groups)
+        [Client.list_deployment_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_groups)
         """
 
     def list_deployment_instances(
@@ -472,7 +478,7 @@ class CodeDeployClient:
         instanceTypeFilter: List[Literal["Blue", "Green"]] = None,
     ) -> ListDeploymentInstancesOutputTypeDef:
         """
-        [Client.list_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_instances)
+        [Client.list_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_instances)
         """
 
     def list_deployment_targets(
@@ -482,28 +488,38 @@ class CodeDeployClient:
         targetFilters: Dict[Literal["TargetStatus", "ServerInstanceLabel"], List[str]] = None,
     ) -> ListDeploymentTargetsOutputTypeDef:
         """
-        [Client.list_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_targets)
+        [Client.list_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_targets)
         """
 
     def list_deployments(
         self,
         applicationName: str = None,
         deploymentGroupName: str = None,
+        externalId: str = None,
         includeOnlyStatuses: List[
-            Literal["Created", "Queued", "InProgress", "Succeeded", "Failed", "Stopped", "Ready"]
+            Literal[
+                "Created",
+                "Queued",
+                "InProgress",
+                "Baking",
+                "Succeeded",
+                "Failed",
+                "Stopped",
+                "Ready",
+            ]
         ] = None,
         createTimeRange: TimeRangeTypeDef = None,
         nextToken: str = None,
     ) -> ListDeploymentsOutputTypeDef:
         """
-        [Client.list_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_deployments)
+        [Client.list_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_deployments)
         """
 
     def list_git_hub_account_token_names(
         self, nextToken: str = None
     ) -> ListGitHubAccountTokenNamesOutputTypeDef:
         """
-        [Client.list_git_hub_account_token_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_git_hub_account_token_names)
+        [Client.list_git_hub_account_token_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_git_hub_account_token_names)
         """
 
     def list_on_premises_instances(
@@ -513,14 +529,14 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListOnPremisesInstancesOutputTypeDef:
         """
-        [Client.list_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_on_premises_instances)
+        [Client.list_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_on_premises_instances)
         """
 
     def list_tags_for_resource(
         self, ResourceArn: str, NextToken: str = None
     ) -> ListTagsForResourceOutputTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.list_tags_for_resource)
         """
 
     def put_lifecycle_event_hook_execution_status(
@@ -532,57 +548,57 @@ class CodeDeployClient:
         ] = None,
     ) -> PutLifecycleEventHookExecutionStatusOutputTypeDef:
         """
-        [Client.put_lifecycle_event_hook_execution_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.put_lifecycle_event_hook_execution_status)
+        [Client.put_lifecycle_event_hook_execution_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.put_lifecycle_event_hook_execution_status)
         """
 
     def register_application_revision(
         self, applicationName: str, revision: RevisionLocationTypeDef, description: str = None
     ) -> None:
         """
-        [Client.register_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.register_application_revision)
+        [Client.register_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.register_application_revision)
         """
 
     def register_on_premises_instance(
         self, instanceName: str, iamSessionArn: str = None, iamUserArn: str = None
     ) -> None:
         """
-        [Client.register_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.register_on_premises_instance)
+        [Client.register_on_premises_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.register_on_premises_instance)
         """
 
     def remove_tags_from_on_premises_instances(
         self, tags: List[TagTypeDef], instanceNames: List[str]
     ) -> None:
         """
-        [Client.remove_tags_from_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.remove_tags_from_on_premises_instances)
+        [Client.remove_tags_from_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.remove_tags_from_on_premises_instances)
         """
 
     def skip_wait_time_for_instance_termination(self, deploymentId: str = None) -> None:
         """
-        [Client.skip_wait_time_for_instance_termination documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.skip_wait_time_for_instance_termination)
+        [Client.skip_wait_time_for_instance_termination documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.skip_wait_time_for_instance_termination)
         """
 
     def stop_deployment(
         self, deploymentId: str, autoRollbackEnabled: bool = None
     ) -> StopDeploymentOutputTypeDef:
         """
-        [Client.stop_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.stop_deployment)
+        [Client.stop_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.stop_deployment)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.untag_resource)
         """
 
     def update_application(
         self, applicationName: str = None, newApplicationName: str = None
     ) -> None:
         """
-        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.update_application)
+        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.update_application)
         """
 
     def update_deployment_group(
@@ -606,7 +622,7 @@ class CodeDeployClient:
         onPremisesTagSet: OnPremisesTagSetTypeDef = None,
     ) -> UpdateDeploymentGroupOutputTypeDef:
         """
-        [Client.update_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Client.update_deployment_group)
+        [Client.update_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Client.update_deployment_group)
         """
 
     @overload
@@ -614,7 +630,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_application_revisions"]
     ) -> ListApplicationRevisionsPaginator:
         """
-        [Paginator.ListApplicationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
+        [Paginator.ListApplicationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
         """
 
     @overload
@@ -622,7 +638,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_applications"]
     ) -> ListApplicationsPaginator:
         """
-        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
+        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
         """
 
     @overload
@@ -630,7 +646,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_configs"]
     ) -> ListDeploymentConfigsPaginator:
         """
-        [Paginator.ListDeploymentConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
+        [Paginator.ListDeploymentConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
         """
 
     @overload
@@ -638,7 +654,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_groups"]
     ) -> ListDeploymentGroupsPaginator:
         """
-        [Paginator.ListDeploymentGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
+        [Paginator.ListDeploymentGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
         """
 
     @overload
@@ -646,7 +662,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_instances"]
     ) -> ListDeploymentInstancesPaginator:
         """
-        [Paginator.ListDeploymentInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
+        [Paginator.ListDeploymentInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
         """
 
     @overload
@@ -654,7 +670,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_targets"]
     ) -> ListDeploymentTargetsPaginator:
         """
-        [Paginator.ListDeploymentTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
+        [Paginator.ListDeploymentTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
         """
 
     @overload
@@ -662,7 +678,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployments"]
     ) -> ListDeploymentsPaginator:
         """
-        [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
+        [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
         """
 
     @overload
@@ -670,7 +686,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_git_hub_account_token_names"]
     ) -> ListGitHubAccountTokenNamesPaginator:
         """
-        [Paginator.ListGitHubAccountTokenNames documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
+        [Paginator.ListGitHubAccountTokenNames documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
         """
 
     @overload
@@ -678,7 +694,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_on_premises_instances"]
     ) -> ListOnPremisesInstancesPaginator:
         """
-        [Paginator.ListOnPremisesInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
+        [Paginator.ListOnPremisesInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
         """
 
     @overload
@@ -686,5 +702,5 @@ class CodeDeployClient:
         self, waiter_name: Literal["deployment_successful"]
     ) -> DeploymentSuccessfulWaiter:
         """
-        [Waiter.DeploymentSuccessful documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
+        [Waiter.DeploymentSuccessful documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
         """
